@@ -13,31 +13,41 @@ class MAUIMAN_EXPORT AccessibilityManager : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(bool singleClick READ singleClick WRITE setSingleClick NOTIFY singleClickChanged)
+    Q_PROPERTY(uint scrollBarPolicy READ scrollBarPolicy WRITE setScrollBarPolicy NOTIFY scrollBarPolicyChanged)
+    Q_PROPERTY(bool playSounds READ playSounds WRITE setPlaySounds NOTIFY playSoundsChanged)
 
 public:
 
     struct DefaultValues
     {
-         static bool isMobile()
+        static bool isMobile()
         {
 #if defined(Q_OS_ANDROID) || defined(Q_OS_IOS) || defined(UBUNTU_TOUCH)
-return true;
+            return true;
 #else
             return QByteArrayList{"1", "true"}.contains(qgetenv("QT_QUICK_CONTROLS_MOBILE"));
 #endif
         }
         static inline const bool singleClick = DefaultValues::isMobile();
+        static inline const bool playSounds = true;
+        static inline const uint scrollBarPolicy = DefaultValues::isMobile() ? 3 : 0;
     };
 
     explicit AccessibilityManager(QObject *parent = nullptr);
 
     bool singleClick() const;
-
-public slots:
     void setSingleClick(bool singleClick);
 
-private slots:
+    uint scrollBarPolicy() const;
+    void setScrollBarPolicy(uint newScrollBarPolicy);
+
+    bool playSounds() const;
+    void setPlaySounds(bool newPlaySounds);
+
+private Q_SLOTS:
     void onSingleClickChanged(bool singleClick);
+    void onScrollBarPolicyChanged(uint scrollBarPolicy);
+    void onPlaySoundsChanged(bool playSounds);
 
 private:
 #if !defined Q_OS_ANDROID
@@ -46,15 +56,18 @@ private:
     MauiMan::SettingsStore *m_settings;
 
     bool m_singleClick = AccessibilityManager::DefaultValues::singleClick;
-
+    uint m_scrollBarPolicy = AccessibilityManager::DefaultValues::scrollBarPolicy;
+    bool m_playSounds = AccessibilityManager::DefaultValues::playSounds;
 
     void sync(const QString &key, const QVariant &value);
     void setConnections();
     void loadSettings();
 
-signals:
 
-    void singleClickChanged(bool singleClick);
+Q_SIGNALS:
+    void singleClickChanged(bool);
+    void scrollBarPolicyChanged(uint);
+    void playSoundsChanged(bool);
 };
 
 }
